photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerremovefrom.h
branchRCL_3
changeset 15 191387a8b767
parent 3 9a9c174934f5
child 19 420f6808bf21
--- a/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerremovefrom.h	Wed Apr 14 15:57:24 2010 +0300
+++ b/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerremovefrom.h	Tue Apr 27 16:37:53 2010 +0300
@@ -40,15 +40,17 @@
 	{
 public:
     /**
      * Two-phase constructor
      * @param aMediaListProvider object that provides the media list
      * @param aContainerType specifies the container type. (Used to determine
      * the correct confirmation note.) Only confirmation notes for EMPXAlbum
      * and EMPXTag are supported. A confirmation note will not be displayed for
      * unsupported types.
      */
 	IMPORT_C static CGlxCommandHandlerRemoveFrom* NewL(
-	    MGlxMediaListProvider* aMediaListProvider, TMPXGeneralCategory aContainerType);
+			MGlxMediaListProvider* aMediaListProvider,
+			TMPXGeneralCategory aContainerType, const TDesC& aFileName);
 	    
 	/** Destructor */
 	IMPORT_C ~CGlxCommandHandlerRemoveFrom();
@@ -79,7 +81,7 @@
 
 private:
     /** Second phase constructor */
-	void ConstructL();
+	void ConstructL(const TDesC& aFileName);
 
     /** Constructor */
 	CGlxCommandHandlerRemoveFrom(MGlxMediaListProvider* aMediaListProvider, TMPXGeneralCategory aContainerType);
@@ -40,15 +40,17 @@
 public:
     /**
-     * Two-phase constructor
-     * @param aMediaListProvider object that provides the media list
-     * @param aContainerType specifies the container type. (Used to determine
-     * the correct confirmation note.) Only confirmation notes for EMPXAlbum
-     * and EMPXTag are supported. A confirmation note will not be displayed for
-     * unsupported types.
-     */
+	 * Two-phase constructor
+	 * @param aMediaListProvider object that provides the media list
+	 * @param aContainerType specifies the container type. (Used to determine
+	 * the correct confirmation note.) Only confirmation notes for EMPXAlbum
+	 * and EMPXTag are supported. A confirmation note will not be displayed for
+	 * unsupported types.
+	 * @param aFileName resource file
+	 */
 	IMPORT_C static CGlxCommandHandlerRemoveFrom* NewL(